import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { AccessibleViewType, AccessibleViewProviderId } from 'vscode/vscode/vs/platform/accessibility/browser/accessibleView';
import { ContextKeyExpr } from 'vscode/vscode/vs/platform/contextkey/common/contextkey';
import { Disposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { AccessibilityVerbositySettingId } from 'vscode/vscode/vs/workbench/contrib/accessibility/browser/accessibilityConfiguration';
import { localize } from 'vscode/vscode/vs/nls';
import { ICommandService } from 'vscode/vscode/vs/platform/commands/common/commands.service';
import { IViewsService } from 'vscode/vscode/vs/workbench/services/views/common/viewsService.service';
import { AccessibilityHelpNLS } from 'vscode/vscode/vs/editor/common/standaloneStrings';

class RunAndDebugAccessibilityHelp {
    constructor() {
        this.priority = 120;
        this.name = 'runAndDebugHelp';
        this.when = ( (ContextKeyExpr.equals('activeViewlet', 'workbench.view.debug')));
        this.type = AccessibleViewType.Help;
    }
    getProvider(accessor) {
        return (
             (new RunAndDebugAccessibilityHelpProvider(accessor.get(ICommandService), accessor.get(IViewsService)))
        );
    }
}
let RunAndDebugAccessibilityHelpProvider = class RunAndDebugAccessibilityHelpProvider extends Disposable {
    constructor(_commandService, _viewsService) {
        super();
        this._commandService = _commandService;
        this._viewsService = _viewsService;
        this.id = AccessibleViewProviderId.RunAndDebug;
        this.verbositySettingKey = AccessibilityVerbositySettingId.Debug;
        this.options = { type: AccessibleViewType.Help };
        this._focusedView = this._viewsService.getFocusedViewName();
    }
    onClose() {
        switch (this._focusedView) {
            case 'Watch':
                this._commandService.executeCommand('workbench.debug.action.focusWatchView');
                break;
            case 'Variables':
                this._commandService.executeCommand('workbench.debug.action.focusVariablesView');
                break;
            case 'Call Stack':
                this._commandService.executeCommand('workbench.debug.action.focusCallStackView');
                break;
            case 'Breakpoints':
                this._commandService.executeCommand('workbench.debug.action.focusBreakpointsView');
                break;
            default:
                this._commandService.executeCommand('workbench.view.debug');
        }
    }
    provideContent() {
        return [
            ( localize(
                6090,
                "The Show Run and Debug view command{0} will open the current view.",
                '<keybinding:workbench.view.debug>'
            )),
            ( localize(
                6091,
                "The Debug: Start Debugging command{0} will start a debug session.",
                '<keybinding:workbench.action.debug.start>'
            )),
            AccessibilityHelpNLS.setBreakpoint,
            ( localize(6092, "Once debugging, the following commands will be available:")),
            ( localize(
                6093,
                "- Debug: Continue command{0} will continue execution until the next breakpoint.",
                '<keybinding:workbench.action.debug.continue>'
            )),
            ( localize(
                6094,
                "- Debug: Step Into command{0} will step into the next function call.",
                '<keybinding:workbench.action.debug.stepInto>'
            )),
            ( localize(
                6095,
                "- Debug: Step Over command{0} will step over the current function call.",
                '<keybinding:workbench.action.debug.stepOver>'
            )),
            ( localize(
                6096,
                "- Debug: Step Out command{0} will step out of the current function call.",
                '<keybinding:workbench.action.debug.stepOut>'
            )),
            ( localize(
                6097,
                'The debug viewlet is comprised of several views that can be focused with the following commands or navigated to via tab then arrow keys:'
            )),
            ( localize(
                6098,
                "- Debug: Focus Breakpoints View command{0} will focus the breakpoints view.",
                '<keybinding:workbench.debug.action.focusBreakpointsView>'
            )),
            ( localize(
                6099,
                "- Debug: Focus Call Stack View command{0} will focus the call stack view.",
                '<keybinding:workbench.debug.action.focusCallStackView>'
            )),
            ( localize(
                6100,
                "- Debug: Focus Variables View command{0} will focus the variables view.",
                '<keybinding:workbench.debug.action.focusVariablesView>'
            )),
            ( localize(
                6101,
                "- Debug: Focus Watch View command{0} will focus the watch view.",
                '<keybinding:workbench.debug.action.focusWatchView>'
            )),
            ( localize(
                6102,
                "The debug console is a Read-Eval-Print-Loop that allows you to evaluate expressions and run commands and can be focused with{0}.",
                '<keybinding:workbench.panel.repl.view.focus>'
            )),
            ( localize(
                6103,
                "The setting {0} controls whether watch variable changes are announced.",
                'accessibility.debugWatchVariableAnnouncements'
            )),
        ].join('\n');
    }
};
RunAndDebugAccessibilityHelpProvider = ( (__decorate([
    ( (__param(0, ICommandService))),
    ( (__param(1, IViewsService)))
], RunAndDebugAccessibilityHelpProvider)));

export { RunAndDebugAccessibilityHelp };
